#!/usr/bin/env python3

import argparse
from six.moves import configparser
from os.path import abspath, dirname, join, isdir, basename
import subprocess

class OmplCfg(object):
    pass

'''
Prerequsite:
    blender in PATH
    numpy in blender's python (commonly shipped)
    scipy in blender's python
'''

def parse_ompl(fn):
    config = configparser.ConfigParser()
    config.read([fn])
    cfg = OmplCfg()
    puzzle_dir = cfg.puzzle_dir = dirname(fn)
    cfg.env_fn = join(puzzle_dir, config.get("problem", "world"))
    cfg.rob_fn = join(puzzle_dir, config.get("problem", "robot"))
    cfg.env_fn_base = basename(cfg.env_fn)
    cfg.rob_fn_base = basename(cfg.rob_fn)
    return cfg, config

def main():
    p = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    config = configparser.ConfigParser()
    p.add_argument('dir', help='OMPL .cfg file for the puzzle')
    p.add_argument('cfg', help='OMPL .cfg file for the puzzle')
    p.add_argument('--sol', help='The solution .npz file for the puzzle')
    p.add_argument('--total_frames', help='Total number of frames to show the path',
                   type=int, default=360)
    p.add_argument('--use_original_path',
                   help='Use the original path instead of simplified path. CAVEAT: the simplifed path may become invalid.',
                   action='store_true')
    args = p.parse_args()
    cfg, _ = parse_ompl(args.cfg)

    calls = ['blender']
    calls += ['-P', 'core_bpy_script.py', '--']
    calls += ['--total_frames', str(args.total_frames)]
    if args.use_original_path:
        calls += ['--use_original_path']
    calls += [cfg.env_fn, cfg.rob_fn, args.sol]
    return subprocess.call(calls)

if __name__ == '__main__':
    main()
